"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.adjustResolveConfig = void 0;

var _core = require("@resolve-js/core");

var _getLog = require("./get-log");

const warningAboutValue = valueName => `The ${valueName} config parameter ignored. This parameter is not customizable for AWS serverless runtime.`;

const messageAboutDefaultValue = valueName => `Setting default ${valueName} for aws serverless runtime`;

const adjustResolveConfig = async resolveConfig => {
  const log = (0, _getLog.getLog)('adjust-resolve-config');
  resolveConfig.target = 'cloud';
  resolveConfig.externalDependencies = ['@resolve-js/eventstore-postgresql', '@resolve-js/readmodel-postgresql'];

  if (resolveConfig.eventstoreAdapter != null) {
    log.warn(warningAboutValue('eventstoreAdapter'));
  }

  log.debug(messageAboutDefaultValue('eventstoreAdapter'));
  resolveConfig.eventstoreAdapter = {
    module: '@resolve-js/eventstore-postgresql',
    options: {
      databaseName: (0, _core.declareRuntimeEnv)('RESOLVE_EVENT_STORE_DATABASE_NAME'),
      host: (0, _core.declareRuntimeEnv)('RESOLVE_EVENT_STORE_CLUSTER_HOST'),
      port: (0, _core.declareRuntimeEnv)('RESOLVE_EVENT_STORE_CLUSTER_PORT'),
      user: (0, _core.declareRuntimeEnv)('RESOLVE_USER_ID'),
      password: (0, _core.declareRuntimeEnv)('RESOLVE_USER_PASSWORD'),
      database: 'postgres'
    }
  };

  if (resolveConfig.staticPath !== 'static') {
    log.warn(warningAboutValue('staticPath'));
  }

  messageAboutDefaultValue('staticPath');
  resolveConfig.staticPath = (0, _core.declareRuntimeEnv)('RESOLVE_CLOUD_STATIC_URL');

  if (resolveConfig.readModelConnectors && resolveConfig.readModelConnectors.default != null) {
    log.warn(warningAboutValue('readModelConnectors.default'));
  }

  if (resolveConfig.readModelConnectors == null) {
    resolveConfig.readModelConnectors = {};
  }

  log.debug(messageAboutDefaultValue('readModelConnectors.default'));
  resolveConfig.readModelConnectors.default = {
    module: '@resolve-js/readmodel-postgresql',
    options: {
      databaseName: (0, _core.declareRuntimeEnv)('RESOLVE_READMODEL_DATABASE_NAME'),
      host: (0, _core.declareRuntimeEnv)('RESOLVE_READMODEL_CLUSTER_HOST'),
      port: (0, _core.declareRuntimeEnv)('RESOLVE_READMODEL_CLUSTER_PORT'),
      user: (0, _core.declareRuntimeEnv)('RESOLVE_USER_ID'),
      password: (0, _core.declareRuntimeEnv)('RESOLVE_USER_PASSWORD'),
      database: 'postgres'
    }
  };
};

exports.adjustResolveConfig = adjustResolveConfig;
//# sourceMappingURL=index.js.map