"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.resetLambdaWorker = exports.default = void 0;

require("source-map-support/register");

var _fs = _interopRequireDefault(require("fs"));

var _lambdaWorker = require("./lambda-worker");

var _utils = require("./utils");

var _runtimeBase = require("@resolve-js/runtime-base");

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

const log = (0, _runtimeBase.getLog)('aws-serverless-entry');
let maybeLambdaWorkerPromise = null;

const main = async (...args) => {
  try {
    if (maybeLambdaWorkerPromise == null) {
      const handlerPath = `${process.env.LAMBDA_TASK_ROOT}/cloud-entry.js`;

      if (handlerPath == null || !_fs.default.existsSync(handlerPath)) {
        throw new Error(`Entry "${handlerPath}" is not provided`);
      }

      process.env.__RUNTIME_ENTRY_PATH = handlerPath;
      const serverAssemblies = (0, _utils.getServerAssemblies)(handlerPath);
      maybeLambdaWorkerPromise = (0, _lambdaWorker.initLambdaWorker)(serverAssemblies);
    }

    const worker = await maybeLambdaWorkerPromise;
    return await worker(...args);
  } catch (error) {
    log.error('Lambda handler fatal error: ', error);
    throw error;
  }
};

const resetLambdaWorker = () => {
  maybeLambdaWorkerPromise = null;
};

exports.resetLambdaWorker = resetLambdaWorker;
var _default = main;
exports.default = _default;
//# sourceMappingURL=index.js.map